.. j2y documentation master file, created by
   sphinx-quickstart on Fri Nov 16 21:40:08 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to j2y's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   render


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
